# Automations Best Practices: Use Cases by Triggers
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers#overview)
  * [Creating Subscriptions for Specific Users on Newly Created Fact Sheets](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers#creating-subscriptions-for-specific-users-on-newly-created-fact-sheets)
  * [Creating Subscriptions for Fact Sheet Creators on Newly Created Fact Sheets](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers#creating-subscriptions-for-fact-sheet-creators-on-newly-created-fact-sheets)
  * [Creating an Action Item for Fact Sheet Creators on Newly Created Fact Sheets](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers#creating-an-action-item-for-fact-sheet-creators-on-newly-created-fact-sheets)
  * [Adding Tags or Setting Single-Select Field Values on Newly Created Fact Sheets](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers#adding-tags-or-setting-single-select-field-values-on-newly-created-fact-sheets)
  * [Changing a Field Value Based on Another Field Value](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers#changing-a-field-value-based-on-another-field-value)
  * [Creating an Action Item on a Field Change](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers#creating-an-action-item-on-a-field-change)
  * [Assigning an Action Item to Subscriptions (Fixed Users) on Lifecycle Phase Changes](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers#assigning-an-action-item-to-subscriptions-\(fixed-users\)-on-lifecycle-phase-changes)


View all
Explore automation examples for specific triggers.
